<?php

declare(strict_types=1);

namespace Drupal\Tests\schemadotorg_commerce_price\Kernel;

use Drupal\Tests\schemadotorg_jsonld\Kernel\SchemaDotOrgJsonLdKernelTestBase;
use Drupal\node\Entity\Node;
use Drupal\schemadotorg_jsonld\SchemaDotOrgJsonLdBuilderInterface;

/**
 * Tests the functionality of the Schema.org Commerce Price module JSON-LD integration.
 *
 * @covers schemadotorg_commerce_price_schemadotorg_jsonld_schema_property_alter(()
 * @group schemadotorg_commerce
 */
class SchemaDotOrgJsonLdKernelTest extends SchemaDotOrgJsonLdKernelTestBase {

  /**
   * {@inheritdoc}
   */
  protected static $modules = [
    'commerce',
    'commerce_price',
    'schemadotorg_commerce_price',
  ];

  /**
   * Schema.org JSON-LD builder.
   */
  protected SchemaDotOrgJsonLdBuilderInterface $builder;

  /**
   * {@inheritdoc}
   */
  protected function setUp(): void {
    parent::setUp();

    \Drupal::moduleHandler()->loadInclude('schemadotorg_commerce_price', 'install');
    schemadotorg_commerce_price_install(FALSE);
  }

  /**
   * Test Schema.org Commerce Price JSON-LD.
   */
  public function testJsonLd(): void {
    \Drupal::currentUser()->setAccount($this->createUser(['access content']));

    $this->createSchemaEntity('node', 'IndividualProduct');

    // Product node.
    $product_node = Node::create([
      'type' => 'individual_product',
      'title' => 'Individual product',
      'schema_offers' => [['number' => '100', 'currency_code' => 'USD']],
    ]);
    $product_node->save();

    $product_jsonld = $this->builder->buildEntity($product_node);

    $this->assertArrayHasKey('offers', $product_jsonld);

    $expected_offer = [
      '@type' => 'Offer',
      'price' => '100',
      'priceCurrency' => 'USD',
    ];
    $this->assertEquals($expected_offer, $product_jsonld['offers']);
  }

}
