<?php

declare(strict_types=1);

namespace Drupal\Tests\schemadotorg_commerce_price\Kernel;

use Drupal\Tests\schemadotorg\Kernel\SchemaDotOrgEntityKernelTestBase;

/**
 * Tests the functionality of the Schema.org Commerce Price module.
 *
 * @covers schemadotorg_commerce_price_install()
 * @covers schemadotorg_commerce_price_uninstall()
 * @group schemadotorg_commerce
 */
class SchemaDotOrgKernelTest extends SchemaDotOrgEntityKernelTestBase {

  /**
   * {@inheritdoc}
   */
  protected static $modules = [
    'commerce',
    'commerce_price',
    'schemadotorg_commerce_price',
  ];

  /**
   * {@inheritdoc}
   */
  protected function setUp(): void {
    parent::setUp();
    $this->installConfig(['schemadotorg_commerce_price']);
  }

  /**
   * Test Schema.org Blueprints Commerce Price installation.
   */
  public function testInstall(): void {
    \Drupal::moduleHandler()->loadInclude('schemadotorg_commerce_price', 'install');

    $config = \Drupal::config('schemadotorg.settings');

    // Check IndividualProduct's default properties.
    $this->assertEquals(NULL, $config->get('schema_types.default_properties.IndividualProduct'));

    // Check QuantitativeValue default field types is 'number'.
    $this->assertEquals(NULL, $config->get('schema_types.default_field_types.Offer'));

    // Install the Schema.org Blueprints Commerce Price module.
    schemadotorg_commerce_price_install(FALSE);

    // Check adding offers to Product's default properties.
    $new_default_properties = [
      'offers',
    ];
    $this->assertEquals($new_default_properties, $config->get('schema_types.default_properties.IndividualProduct'));

    // Check Offer default field types has now also Commerce Price field type.
    $new_default_field_types = [
      'commerce_price',
    ];
    $this->assertEquals($new_default_field_types, $config->get('schema_types.default_field_types.Offer'));

    // Uninstall the Schema.org Blueprints Commerce Price module.
    schemadotorg_commerce_price_uninstall(FALSE);

    // Check QuantitativeValue default field types is 'string_long'.
    $this->assertEquals([], $config->get('schema_types.default_field_types.Offer'));

    // Check removing width, height and weight to Product's default properties.
    $default_properties = [];
    $this->assertEquals($default_properties, $config->get('schema_types.default_properties.IndividualProduct'));
  }

}
