<?php

declare(strict_types=1);

namespace Drupal\Tests\schemadotorg_commerce_product\Kernel;

use Drupal\Tests\schemadotorg_jsonld\Kernel\SchemaDotOrgJsonLdKernelTestBase;
use Drupal\commerce_product\Entity\Product;
use Drupal\commerce_product\Entity\ProductVariation;
use Drupal\schemadotorg_jsonld\SchemaDotOrgJsonLdBuilderInterface;

/**
 * Tests the functionality of the Schema.org Commerce product module JSON-LD integration.
 *
 * @covers schemadotorg_commerce_product_schemadotorg_jsonld_alter(()
 * @group schemadotorg_commerce
 */
class SchemaDotOrgJsonLdKernelTest extends SchemaDotOrgJsonLdKernelTestBase {

  /**
   * {@inheritdoc}
   */
  protected static $modules = [
    'commerce',
    'commerce_price',
    'path',
    'commerce_product',
    'commerce_store',
    'address',
    'entity',
    'schemadotorg_commerce_product',
  ];

  /**
   * Schema.org JSON-LD builder.
   */
  protected SchemaDotOrgJsonLdBuilderInterface $builder;

  /**
   * {@inheritdoc}
   */
  protected function setUp(): void {
    parent::setUp();

    $this->installConfig(['schemadotorg_commerce_product']);

    $this->installEntitySchema('commerce_product');
    $this->installEntitySchema('commerce_product_variation');
    $this->installEntitySchema('commerce_store');

    $this->createSchemaEntity('commerce_product', 'ProductGroup');
    $this->createSchemaEntity('commerce_product_variation', 'Product');

    \Drupal::currentUser()->setAccount($this->createUser(['view commerce_product']));
  }

  /**
   * Test Schema.org Commerce product JSON-LD.
   */
  public function testJsonLd(): void {
    $product_variation = ProductVariation::create([
      // Figure out how the 'tags' product type is set.
      'type' => 'tags',
      'sku' => 'abc',
      'price' => [
        'number' => '100',
        'currency_code' => 'USD',
      ],
    ]);
    $product_variation->save();
    $product = Product::create([
      // Figure out how the 'tags' product type is set.
      'type' => 'tags',
      'title' => 'Product group',
      'variations' => [$product_variation],
    ]);
    $product->save();

    $product_jsonld = $this->builder->buildEntity($product);

    $expected_product = [
      '@type' => 'ProductGroup',
      '@url' => $product->toUrl()->setAbsolute()->toString(),
    ];
    $this->assertEquals($expected_product, $product_jsonld);

    $product_variation_jsonld = $this->builder->buildEntity($product_variation);
    $expected_product_variation = [
      '@type' => 'Product',
      '@url' => $product_variation->toUrl()->setAbsolute()->toString(),
      'isVariantOf' => 'Product group',
      'offers' => [
        '@type' => 'Demand',
        'name' => NULL,
      ],
      'sku' => 'abc',
    ];
    $this->assertEquals($expected_product_variation, $product_variation_jsonld);
  }

}
