<?php

declare(strict_types=1);

namespace Drupal\Tests\schemadotorg_commerce_product\Kernel;

use Drupal\Tests\schemadotorg\Kernel\SchemaDotOrgEntityKernelTestBase;

/**
 * Tests the functionality of the Schema.org Commerce Product module.
 *
 * @covers schemadotorg_commerce_product_install()
 * @covers schemadotorg_commerce_product_uninstall()
 * @group schemadotorg_commerce
 */
class SchemaDotOrgKernelTest extends SchemaDotOrgEntityKernelTestBase {

  /**
   * {@inheritdoc}
   */
  protected static $modules = [
    'commerce_product',
    'schemadotorg_jsonld',
    'schemadotorg_commerce_product',
  ];

  /**
   * {@inheritdoc}
   */
  protected function setUp(): void {
    parent::setUp();
    $this->installConfig(['schemadotorg_jsonld']);
    $this->installConfig(['schemadotorg_commerce_product']);
  }

  /**
   * Test Schema.org Blueprints Commerce Price installation.
   */
  public function testInstall(): void {
    \Drupal::moduleHandler()->loadInclude('schemadotorg_commerce_product', 'install');

    $config = \Drupal::config('schemadotorg_jsonld.settings');

    $initial_schema_type_entity_references_display = [
      'block_content' => 'entity',
      'paragraph' => 'entity',
      'paragraph--layout' => 'none',
      'media' => 'entity',
      'media--image' => '[media:field_media_image:entity:url]',
      'node--Thing' => 'url',
      'node--Intangible' => 'entity',
      'taxonomy_term' => 'entity',
      'Intangible' => 'entity',
    ];
    $this->assertEquals(
      $initial_schema_type_entity_references_display,
      $config->get('schema_type_entity_references_display')
    );

    // Install the Schema.org Blueprints Commerce Product module.
    schemadotorg_commerce_product_install(FALSE);

    $schema_type_entity_references_display = [
      'block_content' => 'entity',
      'paragraph' => 'entity',
      'paragraph--layout' => 'none',
      'media' => 'entity',
      'media--image' => '[media:field_media_image:entity:url]',
      'node--Thing' => 'url',
      'node--Intangible' => 'entity',
      'taxonomy_term' => 'entity',
      'Intangible' => 'entity',
      'commerce_product_variation' => 'entity',
    ];
    $this->assertEquals(
      $schema_type_entity_references_display,
      $config->get('schema_type_entity_references_display')
    );

    // Uninstall the Schema.org Blueprints Commerce Product module.
    schemadotorg_commerce_product_uninstall(FALSE);

    $this->assertEquals(
      $initial_schema_type_entity_references_display,
      $config->get('schema_type_entity_references_display')
    );
  }

}
